API Documentation
=================

Device classes
--------------

.. autoclass:: uhid.UHIDDevice
   :members:
   :undoc-members:
   :noindex:

.. autoclass:: uhid.AsyncUHIDDevice
   :members:
   :undoc-members:
   :noindex:


IO backends
-----------

.. autoclass:: uhid.PolledBlockingUHID
   :members:
   :undoc-members:
   :noindex:

.. autoclass:: uhid.AsyncioBlockingUHID
   :members:
   :undoc-members:
   :noindex:

.. autoclass:: uhid.TrioUHID
   :members:
   :undoc-members:
   :noindex:


Exceptions
----------

.. autoclass:: uhid.UHIDException
   :members:
   :undoc-members:
   :show-inheritance:
   :noindex:


Data
----

.. autoclass:: uhid.Bus
   :members:
   :undoc-members:
   :show-inheritance:
   :noindex:
